package com.zsc.edu.dify.modules.dify.controller;

import io.github.guoshiqiufeng.dify.core.pojo.DifyPageResult;
import io.github.guoshiqiufeng.dify.dataset.DifyDataset;
import io.github.guoshiqiufeng.dify.dataset.dto.request.*;
import io.github.guoshiqiufeng.dify.dataset.dto.response.*;
import jakarta.annotation.Resource;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/v1/dataset")
public class V1DatasetController {
    @Resource
    private DifyDataset difyDataset;
    
    @Value("${dify.dataset.api-key}")
    private String apiKey;

    /**
     * 分页查询知识库
     *
     * @param request
     * @return
     */
    @PostMapping("/page")
    @PreAuthorize("hasAuthority('dify:dataset:query')")
    public DifyPageResult<DatasetResponse> page(@RequestBody DatasetPageRequest request){
        request.setApiKey(apiKey);
        return difyDataset.page(request);
    }

    /**
     * 通过文件创建文档
     *
     * @param request
     * @return
     */
    @PostMapping("/createDocumentByFile")
    @PreAuthorize("hasAuthority('dify:dataset:create')")
    public DocumentCreateResponse createDocumentByFile(DocumentCreateByFileRequest request){
        return difyDataset.createDocumentByFile(request);
    }

    /**
     * 分页查询文档
     *
     * @param request
     * @return
     */
    @GetMapping("/pageDocument")
    @PreAuthorize("hasAuthority('dify:dataset:query')")
    public DifyPageResult<DocumentInfo> pageDocument(@RequestBody DatasetPageDocumentRequest request){
        request.setApiKey(apiKey);
        return difyDataset.pageDocument(request);
    }

    /**
     * 获取上传文件信息
     *
     * @param datasetId
     * @param documentId
     * @return
     */
    @PostMapping("/uploadFileInfo")
    @PreAuthorize("hasAuthority('dify:dataset:query')")
    public UploadFileInfoResponse uploadFileInfo(String datasetId, String documentId){
        return difyDataset.uploadFileInfo(datasetId, documentId,apiKey);
    }

    /**
     * 删除文档
     *
     * @param datasetId
     * @param documentId
     * @return
     */
    @DeleteMapping("/deleteDocument")
    @PreAuthorize("hasAuthority('dify:dataset:delete')")
    public void deleteDocument(String datasetId, String documentId){
        difyDataset.deleteDocument(datasetId, documentId, apiKey);
    }

    /**
     * 创建分段
     *
     * @param request
     * @return
     */
    @PostMapping("/createSegment")
    @PreAuthorize("hasAuthority('dify:dataset:create')")
    public SegmentResponse createSegment(@RequestBody SegmentCreateRequest request){
        return difyDataset.createSegment(request);
    }

    /**
     * 创建子分段
     *
     * @param request
     * @return
     */
    @PostMapping("/createSegmentChildChunk")
    @PreAuthorize("hasAuthority('dify:dataset:create')")
    public SegmentChildChunkCreateResponse createSegmentChildChunk(@RequestBody SegmentChildChunkCreateRequest request){
        return difyDataset.createSegmentChildChunk(request);
    }

    /**
     * 检索
     *
     * @param request
     * @return
     */
    @GetMapping("/retrieve")
    @PreAuthorize("hasAuthority('dify:dataset:query')")
    public RetrieveResponse retrieve(@RequestBody RetrieveRequest request){
        return difyDataset.retrieve(request);
    }
}
