package com.zsc.edu.dify.modules.dify.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.zsc.edu.dify.modules.dify.entity.AppEntity;
import com.zsc.edu.dify.modules.dify.service.DifyServerService;
import io.github.guoshiqiufeng.dify.server.DifyServer;
import io.github.guoshiqiufeng.dify.server.dto.response.ApiKeyResponseVO;
import io.github.guoshiqiufeng.dify.server.dto.response.AppsResponseVO;
import io.github.guoshiqiufeng.dify.server.dto.response.DatasetApiKeyResponseVO;
import jakarta.annotation.Resource;
import org.apache.ibatis.annotations.Param;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/v1/server")
public class V1ServerController {

    @Resource
    private DifyServer difyServer;
    @Resource
    private DifyServerService difyServerService;

    /**
     * 获取应用列表
     * @param mode 模式 chat\agent-chat\completion\advanced-chat\workflow
     * @param name 应用名称，用于过滤应用列表（可选，传入空字符串时表示不过滤）
     * @return
     */
    @GetMapping("/apps")
    @PreAuthorize("hasAuthority('dify:server:query')")
    public List<AppsResponseVO> getApps(String mode, String name) {
        return difyServerService.getApps(mode, name);
    }

    /**
     * 获取应用详情
     * @param id 应用id
     * @return
     */
    @GetMapping("/{id}")
    @PreAuthorize("hasAuthority('dify:server:query')")
    public AppsResponseVO getApp(@PathVariable("id") String id) {
        return difyServer.app(id);
    }

    /**
     * 获取应用api-key
     * @param id 应用id
     * @return
     */
    @GetMapping("/api-key/{id}")
    @PreAuthorize("hasAuthority('dify:server:query')")
    public List<ApiKeyResponseVO> getAppApiKey(@PathVariable("id") String id) {
        return difyServer.getAppApiKey(id);
    }

    /**
     * 初始化应用api-key
     * @param id 应用id
     * @return
     */
    @PostMapping("/api-key/init/{id}")
    @PreAuthorize("hasAuthority('dify:server:create')")
    public List<ApiKeyResponseVO> initAppApiKey(@PathVariable("id") String id) {
        return difyServer.initAppApiKey(id);
    }

    /**
     * 获取知识库api-key
     * @return
     */
    @GetMapping("/api-key/dataset")
    @PreAuthorize("hasAuthority('dify:server:query')")
    public List<DatasetApiKeyResponseVO> getDatasetApiKey() {
        return difyServer.getDatasetApiKey();
    }

    /**
     * 初始化知识库api-key
     * @return
     */
    @PostMapping("/api-key/dataset/init")
    @PreAuthorize("hasAuthority('dify:server:create')")
    public List<DatasetApiKeyResponseVO> initDatasetApiKey() {
        return difyServer.initDatasetApiKey();
    }

    /**
     * 切换启用状态
     *
     * @param id 应用id
     * @return
     */
    @PostMapping("/app/{id}/toggle")
    @PreAuthorize("hasAuthority('dify:server:update')")
    public boolean enabledApp(@PathVariable String id) {
        return difyServerService.enabledApp(id);
    }

    /**
     * 获取可用应用列表
     * @return
     */
    @GetMapping("/apps/enabled")
    @PreAuthorize("hasAuthority('dify:server:query')")
    public List<AppEntity> getEnableApps() {
        LambdaQueryWrapper<AppEntity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(AppEntity::isEnabled, true);
        return difyServerService.list(queryWrapper);
    }

}
