package com.zsc.edu.dify.modules.dify.controller;

import com.zsc.edu.dify.modules.dify.repo.AppEntityRepository;
import io.github.guoshiqiufeng.dify.core.pojo.DifyPageResult;
import io.github.guoshiqiufeng.dify.workflow.DifyWorkflow;
import io.github.guoshiqiufeng.dify.workflow.dto.request.WorkflowLogsRequest;
import io.github.guoshiqiufeng.dify.workflow.dto.request.WorkflowRunRequest;
import io.github.guoshiqiufeng.dify.workflow.dto.response.*;
import jakarta.annotation.Resource;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;

@RestController
@RequestMapping("/api/v1/workflow")
public class V1WorkflowController {

    @Resource
    private DifyWorkflow difyWorkflow;


    @Resource
    private AppEntityRepository appEntityRepository;

    /**
     * 运行工作流
     *
     * @param request
     * @return
     */
    @PostMapping("/run/{appId}")
    @PreAuthorize("hasAuthority('dify:workflow:run')")
    public WorkflowRunResponse runWorkflow(@RequestBody WorkflowRunRequest request,@PathVariable String appId) {
        String apiKey = appEntityRepository.selectApiKey(appId);
        request.setApiKey(apiKey);
        return difyWorkflow.runWorkflow(request);
    }

    /**
     * 运行工作流(流式)
     *
     * @param request
     * @return
     */
    @PostMapping("/run/stream")
    public Flux<WorkflowRunStreamResponse> runWorkflowStream(@RequestBody WorkflowRunRequest request) {
        return difyWorkflow.runWorkflowStream(request);
    }

    /**
     * 停止工作流(流式)
     *
     * @param taskId
     * @param userId
     * @return
     */
    @PatchMapping("/stop/{appId}")
    public WorkflowStopResponse stopWorkflowStream( String taskId, String userId, @PathVariable String appId) {
        String apiKey = appEntityRepository.selectApiKey(appId);
        return difyWorkflow.stopWorkflowStream(apiKey, taskId, userId);
    }

    /**
     * 获取工作流信息
     *
     * @param workflowRunId
     * @return
     */
    @GetMapping("/info/{appId}")
    @PreAuthorize("hasAuthority('dify:workflow:info')")
    public WorkflowInfoResponse info(String workflowRunId, @PathVariable String appId) {
        String apiKey = appEntityRepository.selectApiKey(appId);
        return difyWorkflow.info(workflowRunId, apiKey);
    }

    /**
     * 获取工作流日志
     *
     * @param request
     * @return
     */
    @PostMapping("/logs/{appId}")
    @PreAuthorize("hasAuthority('dify:workflow:log')")
    public DifyPageResult<WorkflowLogs> logs(@RequestBody WorkflowLogsRequest request, @PathVariable String appId) {
        String apiKey = appEntityRepository.selectApiKey(appId);
        request.setApiKey(apiKey);
        final DifyPageResult<WorkflowLogs> logs = difyWorkflow.logs(request);
        return logs;
    }
}
